==> seedsui-react-3.0.4.tgz: package/es/Player/PlayerDialog.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var PlayerDialog = (_temp = _class = function (_Component) {
  _inherits(PlayerDialog, _Component);

  function PlayerDialog(props, context) {
    _classCallCheck(this, PlayerDialog);

    return _possibleConstructorReturn(this, _Component.call(this, props, context));
  }
  // 全局配置


  PlayerDialog.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        src = _props.src,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        _props$videoAttribute = _props.videoAttribute,
        videoAttribute = _props$videoAttribute === undefined ? {} : _props$videoAttribute,
        onHide = _props.onHide;

    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, maskAttribute, { className: 'mask video-mask' + (maskAttribute.className ? ' ' + maskAttribute.className : '') + (show ? ' active' : '') }),
      React.createElement(
        'video',
        _extends({ controls: true }, videoAttribute),
        React.createElement('source', { src: src }),
        '\u60A8\u7684\u6D4F\u89C8\u5668\u4E0D\u652F\u6301 video \u6807\u7B7E\u3002'
      ),
      React.createElement('div', { className: 'voice-line' }),
      React.createElement('div', { className: 'video-close', onClick: onHide })
    ), portal || this.context.portal || document.getElementById('root') || document.body);
  };

  return PlayerDialog;
}(Component), _class.contextTypes = {
  locale: PropTypes.object,
  portal: PropTypes.object
}, _temp);
export { PlayerDialog as default };
PlayerDialog.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool,
  src: PropTypes.string,
  maskAttribute: PropTypes.object,
  videoAttribute: PropTypes.object,
  onHide: PropTypes.func
} : {};

==> seedsui-react-3.7.9.tgz: package/es/Player/PlayerDialog.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';
import Context from '../Context/instance.js';

var PlayerDialog = (_temp = _class = function (_Component) {
  _inherits(PlayerDialog, _Component);

  function PlayerDialog(props, context) {
    _classCallCheck(this, PlayerDialog);

    return _possibleConstructorReturn(this, _Component.call(this, props, context));
  }

  PlayerDialog.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        src = _props.src,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        _props$videoAttribute = _props.videoAttribute,
        videoAttribute = _props$videoAttribute === undefined ? {} : _props$videoAttribute,
        onHide = _props.onHide;

    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, maskAttribute, { className: 'mask video-mask' + (maskAttribute.className ? ' ' + maskAttribute.className : '') + (show ? ' active' : '') }),
      React.createElement(
        'video',
        _extends({ controls: true }, videoAttribute),
        React.createElement('source', { src: src }),
        '\u60A8\u7684\u6D4F\u89C8\u5668\u4E0D\u652F\u6301 video \u6807\u7B7E\u3002'
      ),
      React.createElement('div', { className: 'voice-line' }),
      React.createElement('div', { className: 'video-close', onClick: onHide })
    ), portal || this.context.portal || document.getElementById('root') || document.body);
  };

  return PlayerDialog;
}(Component), _class.contextType = Context, _temp);
export { PlayerDialog as default };
PlayerDialog.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool,
  src: PropTypes.string,
  maskAttribute: PropTypes.object,
  videoAttribute: PropTypes.object,
  onHide: PropTypes.func
} : {};
